emacs-erc
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: 27.1; add libera chat to ERC


From: Alex Murray
Subject: Re: 27.1; add libera chat to ERC
Date: Tue, 25 May 2021 12:09:23 +0930
User-agent: mu4e 1.4.15; emacs 28.0.50


On Tue, 2021-05-25 at 07:33:31 +0930, Andreas Schwab wrote:

On Mai 19 2021, Corwin Brust wrote:

diff --git a/lisp/erc/erc-services.el b/lisp/erc/erc-services.el
index 09d1f7a330..62c9fbdd51 100644
--- a/lisp/erc/erc-services.el
+++ b/lisp/erc/erc-services.el
@@ -32,8 +32,8 @@
;; As a default, ERC has the data for the official nickname services on
 ;; the networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, GRnet,
 ;; and Slashnet.  You can add more by using M-x customize-variable RET
 ;; erc-nickserv-alist.
;; Usage:
 ;;
@@ -197,6 +197,7 @@ Example of use:
                        (const GalaxyNet)
                        (const GRnet)
                        (const iip)
+                        (const Libera)
                        (const OFTC)
                        (const QuakeNet)
                        (const Rizon)
@@ -264,6 +265,15 @@ Example of use:
      "type\\s-/squery\\s-Trent\\s-identify\\s-<password>"
      "Trent@anon.iip"
      "IDENTIFY" nil "SQUERY" nil)
+    (Libera
+     "NickServ!NickServ@services."

NickServ on irc.libera.chat shows as:

NickServ is Nickname Services (NickServ@services.libera.chat)


So I think the above should be:

+     "NickServ!NickServ@services.libera.chat"

+     ;; Libera.Chat also accepts a password at login, see the `erc'
+     ;; :password argument.
+     "This\\s-nickname\\s-is\\s-registered.\\s-Please\\s-choose"
+     "NickServ"
+     "IDENTIFY" nil nil
+     ;; See also the 901 response code message.
+     "You\\s-are\\s-now\\s-identified\\s-for\\s-")
     (OFTC
      "NickServ!services@services.oftc.net"
      ;; OFTC's NickServ doesn't ask you to identify anymore.
@@ -32,8 +32,8 @@
;; As a default, ERC has the data for the official nickname services on
 ;; the networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, GRnet,
-;; and Slashnet.  You can add more by using M-x customize-variable RET
-;; erc-nickserv-alist.
+;; Libera.Chat and Slashnet.  You can add more by using
+;;   M-x customize-variable RET erc-nickserv-alist.
;; Usage:
 ;;

irc.libera.chat identifies itself as Libera.Chat.  Shouldn't that be
used instead of Libera?

Andreas.




reply via email to

[Prev in Thread] Current Thread [Next in Thread]